issSecurities: Get a security list fot a market or a board

Description Usage Arguments

View source: R/moex_api.R

Description

Get a security list fot a market or a board

Usage

1
issSecurities(engine = "stock", market = "shares", board = "", raw = F)

Arguments

raw

apxu-devil/MoexAPI documentation built on June 29, 2020, 12:52 a.m.